@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2014  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,12 +36,12 @@
 #include "libcw.h"
 
 #include "dictionary.h"
-#include "cwwords.h"
+#include "cw_words.h"
+#include "cw_common.h"
 #include "memory.h"
 #include "i18n.h"
 
 
-#include "libcw_internal.h"
 #include "libcw_debug.h"
 
 
@@ -150,58 +150,67 @@ static cw_dictionary_t *dictionaries_head = NULL;
  * plus any mutable pointers that need to be freed on destroying the
  * dictionary.  The const and mutable variants are convenience interfaces.
  */
-static dictionary *
-dictionary_new (dictionary *tail,
-                const char *description, const char *const wordlist[],
-                void *mutable_description, void *mutable_wordlist,
-                void *mutable_wordlist_data)
+static dictionary *dictionary_new(dictionary *tail,
+				  const char *description,
+				  const char *const wordlist[],
+				  void *mutable_description,
+				  void *mutable_wordlist,
+				  void *mutable_wordlist_data)
 {
-  /* Count words in the wordlist, and look for multicharacter entries. */
-  int words = 0;
-  bool is_multicharacter = false;
-  for (int word = 0; wordlist[word]; word++)
-    {
-      is_multicharacter |= strlen (wordlist[word]) > 1;
-      words++;
-    }
+	/* Count words in the wordlist, and look for multicharacter
+	   entries. */
+	int words = 0;
+	bool is_multicharacter = false;
+	for (int word = 0; wordlist[word]; word++) {
+		is_multicharacter |= strlen(wordlist[word]) > 1;
+		words++;
+	}
 
-  /*
-   * Create a new dictionary and fill in the main fields.  Group size is
-   * set to one for multicharacter word lists, five otherwise.
-   */
-  dictionary *dict = safe_malloc (sizeof (*dict));
-  dict->description = description;
-  dict->wordlist = wordlist;
-  dict->wordlist_length = words;
-  dict->group_size = is_multicharacter ? 1 : 5;
-  dict->next = NULL;
+	/* Create a new dictionary and fill in the main fields.  Group
+	   size is set to one for multicharacter word lists, five
+	   otherwise. */
+	dictionary *dict = safe_malloc(sizeof (*dict));
+	dict->description = description;
+	dict->wordlist = wordlist;
+	dict->wordlist_length = words;
+	dict->group_size = is_multicharacter ? 1 : 5;
+	dict->next = NULL;
 
-  /* Add mutable pointers passed in. */
-  dict->mutable_description = mutable_description;
-  dict->mutable_wordlist = mutable_wordlist;
-  dict->mutable_wordlist_data = mutable_wordlist_data;
+	/* Add mutable pointers passed in. */
+	dict->mutable_description = mutable_description;
+	dict->mutable_wordlist = mutable_wordlist;
+	dict->mutable_wordlist_data = mutable_wordlist_data;
 
-  /* Add to the list tail passed in, if any. */
-  if (tail)
-    tail->next = dict;
+	/* Add to the list tail passed in, if any. */
+	if (tail) {
+		tail->next = dict;
+	}
 
-  return dict;
+	return dict;
 }
 
-static dictionary *
-dictionary_new_const (dictionary *tail,
-                      const char *description, const char *const wordlist[])
+
+
+
+
+static dictionary *dictionary_new_const(dictionary *tail,
+					const char *description,
+					const char *const wordlist[])
 {
-  return dictionary_new (tail, description, wordlist, NULL, NULL, NULL);
+	return dictionary_new(tail, description, wordlist, NULL, NULL, NULL);
 }
 
-static dictionary *
-dictionary_new_mutable (dictionary *tail,
-                        char *description, const char *wordlist[],
-                        void *wordlist_data)
+
+
+
+
+static dictionary *dictionary_new_mutable(dictionary *tail,
+					  char *description,
+					  const char *wordlist[],
+					  void *wordlist_data)
 {
-  return dictionary_new (tail, description, wordlist,
-                         description, wordlist, wordlist_data);
+	return dictionary_new(tail, description, wordlist,
+			      description, wordlist, wordlist_data);
 }
 
 
@@ -257,34 +266,6 @@ void dictionary_unload(void)
 
 
 
-/*
- * dictionary_getline()
- *
- * Helper function for cw_dictionaries_read().  Returns the next file line (or
- * false if no more lines), stripped of any trailing nl/cr.
- */
-static bool
-dictionary_getline (FILE *stream, char *buffer, int length, int *line_number)
-{
-  if (!feof (stream) && fgets (buffer, length, stream))
-    {
-      int bytes;
-
-      bytes = strlen (buffer);
-      while (bytes > 0 && strchr ("\r\n", buffer[bytes - 1]))
-        buffer[--bytes] = '\0';
-
-      *line_number += 1;
-      return true;
-    }
-
-  return false;
-}
-
-
-
-
-
 /**
    \brief Parse a line, check if it is a line with comment
 
@@ -490,7 +471,9 @@ cw_dictionary_t *cw_dictionaries_create_from_stream(FILE *stream, const char *fi
 	dictionary *tail = NULL;
 
 	/* Parse input lines to create a new dictionary. */
-	while (dictionary_getline(stream, line, MAX_LINE, &line_number)) {
+	while (cw_getline(stream, line, MAX_LINE + 1)) {
+		line_number++;
+
 		char *new_name;
 
 		if (cw_dictionary_parse_is_comment(line)) {
@@ -863,6 +846,7 @@ const char *get_dictionary_random_word(const dictionary *dict)
 #ifdef CW_DICTIONARY_UNIT_TESTS
 
 
+#include "libcw_test.h"
 
 
 static unsigned int test_cw_dictionary_check_line(void);
