@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2014  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -18,6 +18,16 @@
 */
 
 
+/**
+   \file libcw_alsa.c
+
+   \brief ALSA audio sink.
+*/
+
+
+
+
+
 #include "config.h"
 
 
@@ -26,17 +36,22 @@
 
 
 #include <dlfcn.h> /* dlopen() and related symbols */
-
 #include <alsa/asoundlib.h>
 
+
 #include "libcw.h"
 #include "libcw_alsa.h"
 #include "libcw_debug.h"
+#include "libcw_utils.h"
+#include "libcw_gen.h"
 
 
 #define CW_ALSA_HW_BUFFER_CONFIG  0  /* set up hw buffer/period parameters; unnecessary and probably harmful */
 
 
+
+
+
 extern cw_debug_t cw_debug_object;
 extern cw_debug_t cw_debug_object_ev;
 extern cw_debug_t cw_debug_object_dev;
@@ -168,7 +183,7 @@ bool cw_is_alsa_possible(const char *device)
 int cw_alsa_configure(cw_gen_t *gen, const char *device)
 {
 	gen->audio_system = CW_AUDIO_ALSA;
-	cw_generator_set_audio_device_internal(gen, device);
+	cw_gen_set_audio_device_internal(gen, device);
 
 	gen->open_device  = cw_alsa_open_device_internal;
 	gen->close_device = cw_alsa_close_device_internal;
@@ -206,7 +221,7 @@ int cw_alsa_write_internal(cw_gen_t *gen)
 /**
    \brief Open ALSA output, associate it with given generator
 
-   You must use cw_generator_set_audio_device_internal() before calling
+   You must use cw_gen_set_audio_device_internal() before calling
    this function. Otherwise generator \p gen won't know which device to open.
 
    \param gen - current generator
@@ -376,8 +391,8 @@ int cw_alsa_set_hw_params_internal(cw_gen_t *gen, snd_pcm_hw_params_t *hw_params
 		if (!rv) {
 			if (rate != cw_supported_sample_rates[i]) {
 				cw_debug_msg ((&cw_debug_object_dev), CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING, "cw_alsa: imprecise sample rate:");
-				cw_debug_msg ((&cw_debug_object_dev), CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING, "cw_alsa: asked for: %d", cw_supported_sample_rates[i]);
-				cw_debug_msg ((&cw_debug_object_dev), CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING, "cw_alsa: got:       %d", rate);
+				cw_debug_msg ((&cw_debug_object_dev), CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING, "cw_alsa: asked for: %u", cw_supported_sample_rates[i]);
+				cw_debug_msg ((&cw_debug_object_dev), CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING, "cw_alsa: got:       %u", rate);
 			}
 			success = true;
 			gen->sample_rate = rate;
@@ -707,7 +722,6 @@ void cw_alsa_drop(cw_gen_t *gen)
 
 #include <stdbool.h>
 #include "libcw_alsa.h"
-#include "libcw_internal.h"
 
 
 
