@@ -21,6 +21,15 @@
 #include "config.h"
 
 
+
+
+
+
+
+
+
+
+
 #define _XOPEN_SOURCE 600 /* signaction() + SA_RESTART */
 
 
@@ -53,6 +62,8 @@
 
 
 
+#ifdef LIBCW_UNIT_TESTS
+
 
 
 typedef struct {
@@ -83,6 +94,16 @@ static void cw_test_helper_tq_callback(void *data);
 
 
 
+/* This variable will be used in "forever" test. This test function
+   needs to open generator itself, so it needs to know the current
+   audio system to be used. _NONE is just an initial value, to be
+   changed in test setup. */
+static int test_audio_system = CW_AUDIO_NONE;
+
+
+
+
+
 /* Tone queue module. */
 static void test_tone_queue_1(cw_test_stats_t *stats);
 static void test_tone_queue_2(cw_test_stats_t *stats);
@@ -98,7 +119,7 @@ static void test_keyer(cw_test_stats_t *stats);
 static void test_straight_key(cw_test_stats_t *stats);
 /* Other functions. */
 static void test_parameter_ranges(cw_test_stats_t *stats);
-static void test_cw_forever(cw_test_stats_t *stats);
+static void test_cw_gen_forever_public(cw_test_stats_t *stats);
 
 // static void cw_test_delayed_release(cw_test_stats_t *stats);
 
@@ -1545,38 +1566,30 @@ void cw_test_signal_handling(cw_test_stats_t *stats)
 
 
 
-extern cw_gen_t *cw_generator;
 
+/*
+  Version of test_cw_gen_forever() to be used in libcw_test_internal
+  test executable.
 
-
-void test_cw_forever(cw_test_stats_t *stats)
+  Because the function calls cw_generator_delete(), it should be
+  executed as last test in test suite (unless you want to call
+  cw_generator_new/start() again). */
+void test_cw_gen_forever_public(cw_test_stats_t *stats)
 {
-	int sleep_period = 5;
-	printf("libcw: %s() (%d seconds):\n", __func__, sleep_period);
+	/* Make sure that an audio sink is closed. If we try to open
+	   an OSS sink that is already open, we may end up with
+	   "resource busy" error in libcw_oss.c module (that's what
+	   happened on Alpine Linux).
 
-	sleep(1);
-	cw_tone_t tone;
+	   Because of this call this test should be executed as last
+	   one. */
+	cw_generator_delete();
 
-	tone.usecs = 100;
-	tone.frequency = 500;
-	tone.slope_mode = CW_SLOPE_MODE_RISING_SLOPE;
-	cw_tq_enqueue_internal(cw_generator->tq, &tone);
+	int seconds = 5;
+	printf("libcw: %s() (%d seconds):\n", __func__, seconds);
 
-	tone.slope_mode = CW_SLOPE_MODE_NO_SLOPES;
-	tone.usecs = CW_AUDIO_FOREVER_USECS;
-	tone.frequency = 500;
-	int rv = cw_tq_enqueue_internal(cw_generator->tq, &tone);
-	rv ? stats->successes++ : stats->failures++;
-
-	struct timespec t;
-	cw_usecs_to_timespec_internal(&t, sleep_period * 1000000);
-	cw_nanosleep_internal(&t);
-
-	tone.usecs = 100;
-	tone.frequency = 500;
-	tone.slope_mode = CW_SLOPE_MODE_FALLING_SLOPE;
-	rv = cw_tq_enqueue_internal(cw_generator->tq, &tone);
-	rv ? stats->successes++ : stats->failures++;
+	unsigned int rv = test_cw_gen_forever_sub(seconds, test_audio_system, NULL);
+	rv == 0 ? stats->successes++ : stats->failures++;
 
 	CW_TEST_PRINT_FUNCTION_COMPLETED (__func__);
 
@@ -1655,7 +1668,7 @@ static void (*const CW_TEST_FUNCTIONS_DEP_K[])(cw_test_stats_t *) = {
    Other modules' functions. */
 static void (*const CW_TEST_FUNCTIONS_DEP_O[])(cw_test_stats_t *) = {
 	test_parameter_ranges,
-	test_cw_forever,
+	test_cw_gen_forever_public,
 
 	//cw_test_delayed_release,
 	//cw_test_signal_handling, /* FIXME - not sure why this test fails :( */
@@ -1684,6 +1697,8 @@ static void (*const CW_TEST_FUNCTIONS_DEP_O[])(cw_test_stats_t *) = {
 */
 int cw_test_dependent_with(int audio_system, const char *modules, cw_test_stats_t *stats)
 {
+	test_audio_system = audio_system;
+
 	int rv = cw_generator_new(audio_system, NULL);
 	if (rv != 1) {
 		fprintf(stderr, "libcw: can't create generator, stopping the test\n");
@@ -1823,64 +1838,6 @@ int cw_test_dependent(const char *audio_systems, const char *modules)
 
 
 
-/**
-   \return EXIT_SUCCESS if all tests complete successfully,
-   \return EXIT_FAILURE otherwise
-*/
-int main(int argc, char *const argv[])
-{
-	static const int SIGNALS[] = { SIGHUP, SIGINT, SIGQUIT, SIGPIPE, SIGTERM, 0 };
-
-	unsigned int testset = 0;
-
-	struct timeval seed;
-	gettimeofday(&seed, NULL);
-	// fprintf(stderr, "seed: %d\n", (int) seed.tv_usec);
-	srand(seed.tv_usec);
-
-	/* Obtain a bitmask of the tests to run from the command line
-	   arguments. If none, then default to ~0, which effectively
-	   requests all tests. */
-	if (argc > 1) {
-		testset = 0;
-		for (int arg = 1; arg < argc; arg++) {
-			unsigned int test = strtoul(argv[arg], NULL, 0);
-			testset |= 1 << test;
-		}
-	} else {
-		testset = ~0;
-	}
-
-#define CW_SYSTEMS_MAX 5
-	char sound_systems[CW_SYSTEMS_MAX + 1];
-#define CW_MODULES_MAX 4  /* g, t, k, o */
-	char modules[CW_MODULES_MAX + 1];
-	modules[0] = '\0';
-
-	if (!cw_test_args(argc, argv, sound_systems, CW_SYSTEMS_MAX, modules, CW_MODULES_MAX)) {
-		cw_test_print_help(argv[0]);
-		exit(EXIT_FAILURE);
-	}
-
-	atexit(cw_test_print_stats);
-
-	/* Arrange for the test to exit on a range of signals. */
-	for (int i = 0; SIGNALS[i] != 0; i++) {
-		if (!cw_register_signal_handler(SIGNALS[i], SIG_DFL)) {
-			fprintf(stderr, "libcw: ERROR: cw_register_signal_handler\n");
-			exit(EXIT_FAILURE);
-		}
-	}
-
-	int rv = cw_test_dependent(sound_systems, modules);
-
-	return rv == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
-}
-
-
-
-
-
 void cw_test_print_stats(void)
 {
 	printf("\n\nlibcw: Statistics of tests:\n\n");
@@ -1935,3 +1892,72 @@ void cw_test_print_stats(void)
 
 	return;
 }
+
+
+
+
+
+#endif // #ifdef LIBCW_UNIT_TESTS
+
+
+
+
+
+/**
+   \return EXIT_SUCCESS if all tests complete successfully,
+   \return EXIT_FAILURE otherwise
+*/
+int main(int argc, char *const argv[])
+{
+	int rv = 0;
+
+#ifdef LIBCW_UNIT_TESTS
+	static const int SIGNALS[] = { SIGHUP, SIGINT, SIGQUIT, SIGPIPE, SIGTERM, 0 };
+
+	unsigned int testset = 0;
+
+	struct timeval seed;
+	gettimeofday(&seed, NULL);
+	// fprintf(stderr, "seed: %d\n", (int) seed.tv_usec);
+	srand(seed.tv_usec);
+
+	/* Obtain a bitmask of the tests to run from the command line
+	   arguments. If none, then default to ~0, which effectively
+	   requests all tests. */
+	if (argc > 1) {
+		testset = 0;
+		for (int arg = 1; arg < argc; arg++) {
+			unsigned int test = strtoul(argv[arg], NULL, 0);
+			testset |= 1 << test;
+		}
+	} else {
+		testset = ~0;
+	}
+
+#define CW_SYSTEMS_MAX 5
+	char sound_systems[CW_SYSTEMS_MAX + 1];
+#define CW_MODULES_MAX 4  /* g, t, k, o */
+	char modules[CW_MODULES_MAX + 1];
+	modules[0] = '\0';
+
+	if (!cw_test_args(argc, argv, sound_systems, CW_SYSTEMS_MAX, modules, CW_MODULES_MAX)) {
+		cw_test_print_help(argv[0]);
+		exit(EXIT_FAILURE);
+	}
+
+	atexit(cw_test_print_stats);
+
+	/* Arrange for the test to exit on a range of signals. */
+	for (int i = 0; SIGNALS[i] != 0; i++) {
+		if (!cw_register_signal_handler(SIGNALS[i], SIG_DFL)) {
+			fprintf(stderr, "libcw: ERROR: cw_register_signal_handler\n");
+			exit(EXIT_FAILURE);
+		}
+	}
+
+	rv = cw_test_dependent(sound_systems, modules);
+
+#endif // #ifdef LIBCW_UNIT_TESTS
+
+	return rv == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
+}
